summaryrefslogtreecommitdiffstats
path: root/src/gui/general/RosegardenCanvasView.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-09-06 20:59:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-09-06 20:59:29 +0000
commit11f31c37e5fa4889d9989f10272f44845449cb7b (patch)
tree4383da04a76c497950d957fc6120b0fd0d9082c2 /src/gui/general/RosegardenCanvasView.h
parent832eb69d571e8e518db45d0c0e6fbc0f00690209 (diff)
downloadrosegarden-11f31c37e5fa4889d9989f10272f44845449cb7b.tar.gz
rosegarden-11f31c37e5fa4889d9989f10272f44845449cb7b.zip
Initial TQt conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/rosegarden@1172292 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/gui/general/RosegardenCanvasView.h')
-rw-r--r--src/gui/general/RosegardenCanvasView.h52
1 files changed, 26 insertions, 26 deletions
diff --git a/src/gui/general/RosegardenCanvasView.h b/src/gui/general/RosegardenCanvasView.h
index 509c1aa..3096334 100644
--- a/src/gui/general/RosegardenCanvasView.h
+++ b/src/gui/general/RosegardenCanvasView.h
@@ -26,23 +26,23 @@
#ifndef _RG_ROSEGARDENCANVASVIEW_H_
#define _RG_ROSEGARDENCANVASVIEW_H_
-#include <qpoint.h>
-#include <qtimer.h>
-#include <qcanvas.h>
-#include <qdatetime.h>
-#include <qwmatrix.h>
+#include <tqpoint.h>
+#include <tqtimer.h>
+#include <tqcanvas.h>
+#include <tqdatetime.h>
+#include <tqwmatrix.h>
-class QWidget;
-class QWheelEvent;
-class QScrollBar;
-class QResizeEvent;
+class TQWidget;
+class TQWheelEvent;
+class TQScrollBar;
+class TQResizeEvent;
namespace Rosegarden
{
/**
* A QCanvasView with an auxiliary horiz. scrollbar
* That scrollbar should be provided by the parent widget
* (typically an EditView). The RosegardenCanvasView keeps
* the auxilliary horiz. scrollbar range in sync with the
@@ -53,8 +53,8 @@ class RosegardenCanvasView : public QCanvasView
{
Q_OBJECT
public:
- RosegardenCanvasView(QCanvas*,
- QWidget* parent=0, const char* name=0, WFlags f=0);
+ RosegardenCanvasView(TQCanvas*,
+ TQWidget* parent=0, const char* name=0, WFlags f=0);
/**
* EditTool::handleMouseMove() returns a OR-ed combination of these
@@ -76,7 +76,7 @@ public:
* Sets the widget which will be between the scrollable part of the view
* and the horizontal scrollbar
*/
- void setBottomFixedWidget(QWidget*);
+ void setBottomFixedWidget(TQWidget*);
void updateBottomWidgetGeometry();
@@ -84,12 +84,12 @@ public:
* Sets the widget which will be between the scrollable part of the view
* and the left edge of the view.
*/
- void setLeftFixedWidget(QWidget*);
+ void setLeftFixedWidget(TQWidget*);
void updateLeftWidgetGeometry();
/// Map a point with the inverse world matrix
- QPoint inverseMapPoint(const QPoint& p) { return inverseWorldMatrix().map(p); }
+ TQPoint inverseMapPoint(const TQPoint& p) { return inverseWorldMatrix().map(p); }
void setSmoothScroll(bool s) { m_smoothScroll = s; }
@@ -99,7 +99,7 @@ public:
bool isAutoScrolling() const { return m_autoScrolling; }
- virtual void wheelEvent(QWheelEvent *);
+ virtual void wheelEvent(TQWheelEvent *);
public slots:
/// Update the RosegardenCanvasView after a change of content
@@ -135,7 +135,7 @@ public slots:
/**
* Set the x and y scrollbars to a particular position
*/
- void slotSetScrollPos(const QPoint &);
+ void slotSetScrollPos(const TQPoint &);
void startAutoScroll();
void startAutoScroll(int directionConstraint);
@@ -150,30 +150,30 @@ signals:
protected:
- virtual void resizeEvent(QResizeEvent*);
- virtual void setHBarGeometry(QScrollBar &hbar, int x, int y, int w, int h);
+ virtual void resizeEvent(TQResizeEvent*);
+ virtual void setHBarGeometry(TQScrollBar &hbar, int x, int y, int w, int h);
- virtual QScrollBar* getMainHorizontalScrollBar() { return horizontalScrollBar(); }
+ virtual TQScrollBar* getMainHorizontalScrollBar() { return horizontalScrollBar(); }
//--------------- Data members ---------------------------------
enum ScrollDirection { None, Top, Bottom, Left, Right };
- QWidget* m_bottomWidget;
+ TQWidget* m_bottomWidget;
int m_currentBottomWidgetHeight;
- QWidget* m_leftWidget;
+ TQWidget* m_leftWidget;
bool m_smoothScroll;
int m_smoothScrollTimeInterval;
float m_minDeltaScroll;
- QTime m_scrollTimer;
- QTime m_scrollAccelerationTimer;
+ TQTime m_scrollTimer;
+ TQTime m_scrollAccelerationTimer;
- QTimer m_autoScrollTimer;
+ TQTimer m_autoScrollTimer;
int m_autoScrollTime;
int m_autoScrollAccel;
- QPoint m_previousP;
+ TQPoint m_previousP;
int m_autoScrollXMargin;
int m_autoScrollYMargin;
ScrollDirection m_currentScrollDirection;
@@ -26,23 +26,23 @@
{
/**
- * A QCanvasView with an auxiliary horiz. scrollbar
+ * A TQCanvasView with an auxiliary horiz. scrollbar
* That scrollbar should be provided by the parent widget
* (typically an EditView). The RosegardenCanvasView keeps